########################################################################
#
# predefine is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
#
########################################################################
#
#  Project      :  File Preprocessor - predefine macro
#  Filename     :  $RCSfile: predefine.pm,v $
#  Author       :  $Author: darren $
#  Maintainer   :  Darren Miller: darren@cabaret.demon.co.uk
#  File version :  $Revision: 1.1 $
#  Last changed :  $Date: 2008/11/08 21:18:24 $
#  Description  :  Define a macro from the value of another macro
#  Licence      :  GNU copyleft
#
########################################################################
# THIS IS A FILEPP MODULE, YOU NEED FILEPP TO USE IT!!!
# usage: filepp -m predefine.pm <files>
########################################################################

#  #predefine macro defn
#     The  #predefine  macro  works  the  same  as the #define keyword
#     except any macros in defn are replaced at the time of the  defi-
#     nition, rather than waiting until the macro is used.


package Predefine;

use strict;

# version number of module
my $VERSION = '1.0.0';

##############################################################################
# predefine keyword, macro defn
##############################################################################
sub Predefine
{
    my $macrodefn = shift;
    my $macro;
    my $defn;
    my $i;

    # check there is an argument
    if($macrodefn !~ /\S/o) {
	Filepp::Error("predefine keyword used without arguments");
    }

    Filepp::Debug("PREDEFINE replacing <$macrodefn>");
    # find end of macroword - assume separated by space or tab
    $i = Filepp::GetNextWordEnd($macrodefn);
    
    # separate macro and defn (can't use split, doesn't work with '0')
    $macro = substr($macrodefn, 0, $i);
    $defn  = substr($macrodefn, $i);
    $defn = Filepp::ReplaceDefines($defn);

    Filepp::Define($macro." ".$defn);
}

##############################################################################
# add predefine keyword - also an ifword
##############################################################################
Filepp::AddKeyword("predefine", "Predefine::Predefine");

return 1;

########################################################################
# End of file
########################################################################
