# WARNING: This file is maintained by config
# do not edit this file. Edit the master.
# any changes added here will be lost.
## $Id: template.fpp 9571 2008-11-22 16:17:47Z rouilj $
##
##
## Other notes:
## The form used for the iptables rules should be taken from
## a valid rule as shown by iptables-save. That allows you to get the
## parameter order and form correct.
##
## Note that iptables-save always saves in netmask form, but cdir
## notiation is often easier to read, so the conversion process substitutes
## /16, /22, /24 and /28 into netmask format for you.
##
## Also may want to include internal/external interfaces to suppliment
## 192.168/16 addresses (e.g. -i eth0) and use -i eth1 for non-internal
## ip's.   
#pragma filepp UseModule foreach.pm
#include "filepp.classes"
#foreachdelim /\s+/

#if "LOCALNET" !~ /^[0-9.]+\/[0-9.]+$/
  #error LOCALNET not properly defined should be ip/netmask is 'LOCALNET'
#endif

#if "LOCALIP" !~ /^[0-9.]+$/
  #error LOCALIP not properly defined should be ip is 'LOCALIP'
#endif

*nat
:PREROUTING ACCEPT [0:0]
:POSTROUTING ACCEPT [0:0]
:OUTPUT ACCEPT [0:0]

# PREROUTING rules
####################################################################################

# POSTROUTING rules
####################################################################################

#if "SERVICES" =~ /VPNOPEN/
#####P* iptables/VPNOPEN
### POLICY
### Rules for openvpn natting of addresses
### APPLIES TO
### hosts in VPNOPEN
### SYNOPSIS
### set the source address of packets received from openvpn clients
### DESCRIPTION
### Rewrite the source address (which for the clients is on the
### 172.16.1.0 net) to the internal address of the openvpn server if
### the packet is to be routed out the eth0 interface, and to the
### external address of the openvpn server if it is to be routed out
### any other interface.
###
### Note that these rules are automatically installed by the ovpn.up
### script pushed to the openvpn servers. So changes to these rules
### require corresponding changes to the ovpn.up script to prevent
### duplicate or conflicitng rules.
#####
-A POSTROUTING -s 172.16.1.0/255.255.255.0 -o eth0 -j SNAT --to-source LOCALIP 
-A POSTROUTING -s 172.16.1.0/255.255.255.0 -o ! eth0 -j SNAT --to-source EXTOPENVPNIP
#endif

COMMIT


# we don't use mangle rules yet. Here for future expansion 
*mangle
:PREROUTING ACCEPT [0:0]
:INPUT ACCEPT [0:0]
:FORWARD ACCEPT [0:0]
:OUTPUT ACCEPT [0:0]
:POSTROUTING ACCEPT [0:0]
COMMIT

*filter
:INPUT DROP [0:0]
:FORWARD DROP [0:0]
:OUTPUT ACCEPT [0:0]

# Set up a blacklist that is locally maintained and can be used to block
# hosts ssh login failures
#if "SERVICES" =~ /SSHDEXT/
:BLACKLIST - [0:0]
#endif

:IN - [0:0]

# User defined tables
#  Try to keep user defined tables with lowercase names to avoid confusion
#if "SERVICES" =~ /VPNOPEN/
:ROUTING - [0:0]
#endif

#if "SERVICES" =~ /NFSSERV/
:nfs_clients - [0:0]
#endif

# INPUT rules
####################################################################################

## ssh rules for ssh blacklist
#if "SERVICES" =~ /SSHDEXT/
-A INPUT -p tcp -m tcp --dport 22 -m state --state NEW -j BLACKLIST 
#endif

-A INPUT -j IN 

## Log all default drops on 192.168.x. It's either badly configured  
## software or a missing rule to add to the firewall list to explictly
## drop/allow packets. Can also detect internal scans.
-A INPUT -s 192.168.0.0/16 -m limit --limit 1/min --limit-burst 10 -j LOG --log-prefix "** Drop INPUT: "

#if "SERVICES" =~ /VPNOPEN/
# add the routing table to the forward chain
-A FORWARD -j ROUTING
## Log all default drops from 172.16.1.x on VPNOPEN hosts. It's either   
## badly configured software or a missing rule to add to the firewall
## list to explictly drop/allow packets. Can also detect internal
## scans.
-A FORWARD -s 172.16.1.0/24 -m limit --limit 1/min --limit-burst 10 -j LOG --log-prefix "** Drop 172.16.1.x FORWARD: " 
#endif

## Log all default drops on 192.168.x. It's either badly configured  
## software or a missing rule to add to the firewall list to explictly
## drop/allow packets. Can also detect internal scans.
-A FORWARD -s 192.168.0.0/16 -m limit --limit 1/min --limit-burst 10 -j LOG --log-prefix "** Drop FORWARD: " 

## for forward reject with icmp-host-prohibited
-A FORWARD -j REJECT --reject-with icmp-host-prohibited 

# IN rules
####################################################################################

#if "SERVICES" =~ /VPNOPEN/
## use udp port 1194
-A IN -p udp -m state --state NEW -m udp --dport 1194 -j ACCEPT
#endif

#if "SERVICES" =~ /SMBD/
# allow smb ports 137/138 in
-A IN -s 192.168.0.0/255.255.0.0 -p udp -m state --state NEW -m udp --dport 137 -j ACCEPT 
-A IN -s 192.168.0.0/255.255.0.0 -p udp -m state --state NEW -m udp --dport 138 -j ACCEPT 
#else
  #if "CLUSTER" =~ /(?i)site_lax1/
	# discard these ports w/o logging if in lax1 since the windows
        # clients up there broadcast to these ports causing logging noise.
-A IN -s 192.168.0.0/255.255.0.0 -p udp -m udp --dport 137 -j DROP
-A IN -s 192.168.0.0/255.255.0.0 -p udp -m udp --dport 138 -j DROP
  #endif
#endif

#if "SERVICES" =~ /TFTP/
-A IN -s LOCALNET -p udp -m udp --dport 69 -j ACCEPT 
#endif

#if "SERVICES" =~ /SYSLOGSM/
-A IN -s LOCALNET -p udp -m udp --dport 514 -j ACCEPT 
#endif

#if "SERVICES" =~ /SYSLOGM/
-A IN -s 192.168.0.0/255.255.0.0 -p udp -m udp --dport 514 -j ACCEPT 
#endif

## Need to open the bootp client port to allow nagios to monitor
## the bootp server at a site. The source ip can be restricted to just
# the local site
#if "SERVICES" =~ /\bDHCPTEST\b/
-A IN -s LOCALNET -p udp -m udp --dport 68 -j ACCEPT 
# ignore dhcp broadcasts sent to the dhcptest machine by hosts that are
# booting, or other dhcptest hosts.
-A IN -p udp -m udp --sport 68 --dport 67 -j DROP 
#else
  #if "SERVICES" =~ /DHCP1/ 
-A IN -p tcp -m tcp --dport 67 -j ACCEPT 
-A IN -p udp -m udp --dport 67 -j ACCEPT 
  #else
# because of the broadcast nature of DHCP, all systems see the
# packet. If we aren't a DHCP server, just drop the packet  
# without logging. Note that because of testing of the server
# there will be a few hundred per day.
-A IN -p udp -m udp --sport 68 --dport 67 -j DROP
-A IN -p udp -m udp --sport 67 --dport 68 -j DROP
  #endif
#endif

#if "SERVICES" =~ /\b(LDAP|LDAPMASTER)\b/
-A IN -s 192.168.0.0/16 -p tcp -m tcp --dport 636 -m state --state NEW -j ACCEPT
#endif

## ssh firewall rules
#if "SERVICES" =~ /SSHDEXT/
# allow all ssh traffic
-A IN -p tcp -m tcp --dport 22 -m state --state NEW -j ACCEPT 
#else
  #if "SERVICES" =~ /SSHD/
# allow internal ssh traffic only
    #if "OS" =~ /FEDORA_2/
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT 
    #else
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 22 -m state --state NEW -j ACCEPT 
    #endif
  #endif
#endif

#####P* iptables/NFSSERV
### POLICY
### Access lists nfs in site_lax1
### APPLIES TO
### hosts in NFSSERV
### SYNOPSIS
### Hosts allow nfs clients to connect
### DESCRIPTION
### Allow access to ports 111,632,633,634,635,2049 from appropriate hosts
#####

#if "SERVICES" =~ /NFSSERV/ && "CLUSTER" =~ /site_lax1/
# nfs port settings. Need appropriate /etc/sysconfig/nfs
-A IN -p tcp -m state --state NEW -m multiport --dports 111,632,633,634,635,2049 -m tcp -j nfs_clients
#endif


#####P* iptables/NTP, iptables/port/123
### POLICY
### Access list for top level ntp servers
### APPLIES TO
### All top level ntp servers
### SYNOPSIS
### Allow access to ntp servers from internal and selected external hosts
### DESCRIPTION
### Allow access to port 123/udp
#####
-A IN -s 192.168.0.0/16 -p udp -m udp --dport 123 -j ACCEPT 
#foreach NTP_IP EXTERNAL_NTP_CLIENTS
-A IN -s NTP_IP -p udp -m udp --dport 123 -j ACCEPT 
#endforeach

#####P* iptables/snmp, iptables/port/161
### POLICY
### Access list for snmp servers
### APPLIES TO
### all hosts
### SYNOPSIS
### Allow access to snmp servers from cacti and nagios servers.
### DESCRIPTION
### Allow access to port 161 from cacti and nagios servers.
#####
#foreach SNMP_IP SNMP_COLLECTOR_IPS
-A IN -s SNMP_IP -p udp -m udp --dport 161 -j ACCEPT 
#endforeach

#####P* iptables/DNS
### POLICY
### Accept UDP dns replies
### APPLIES TO
### Any host using DROPDNSRETURN
### SYNOPSIS
### For host that drop a lot of dns reply packets.
### The packets come from the DNS server IP's and are sourced from port 53.
### cause of the drop is unknown. May be:
###   * udp reply takes > than 30 second lifetime of the udp "established"
###     connection
###   * bug in the "established" code for udp packets for these firewalls
### In any case rather than trying to figure it out, tag these hosts with
### DROPSDNSRETURN in the uses clause to enable accepting packets sourced
### from 192.168.x.x at port 53.
#####
#if "USES" =~ /\bDROPDNSRETURN\b/
-A IN -s 192.168.0.0/16 -i eth0 -p udp -m udp --sport 53 -j ACCEPT
#endif

#if "SERVICES" =~ /DNSCACHE/
## allow access to dnscache on port 53 udp
-A IN -s 192.168.0.0/255.255.0.0 -p udp -m udp --dport 53 -j ACCEPT 
#endif

#####P* iptables/dns/external
### POLICY
### Allow any host access to external DNS server
### APPLIES TO
### hosts in DNSEXT class
### SYNOPSIS
### Allow port 53 udp for all hosts not in the 192.168.0.0/16 net.
#####
#if "SERVICES" =~ /DNSEXT/
-A IN -s ! 192.168.0.0/255.255.0.0 -p udp -m udp --dport 53 -j ACCEPT 
#endif

#####P* iptables/MAIL1, iptables/MAIL2
### POLICY
### Access lists for email
### APPLIES TO
### hosts in MAIL1 or MAIL2 class, hosts in MAILINT class
### SYNOPSIS
### Hosts support smtp and smtps. for machines on 192.168.0.0/16 net.
### If not in MAILINT group, supports smtp and smtps for any host.
### DESCRIPTION
### Allow access to ports 25 and 465 from all 192.168.0.0/16 hosts UNLESS
### machine is part of MAILINT group. If part of MAILINT only allows
### access to ports 25 and 465 from hosts on 192.168.0.0/16.
#####

#if "SERVICES" =~ /MAIL[12]/
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 25 -j ACCEPT
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 465 -j ACCEPT
    #if "SERVICES" !~ /MAILINT/
-A IN -s ! 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 25 -j ACCEPT
-A IN -s ! 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 465 -j ACCEPT
    #endif
#endif

#if "SERVICES" =~ /APACHE|TOMCAT/
# allow http traffic for both tomcat (via kernel mucking rules) and 
# apache bound to port 80 and directly for internal hosts
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m state --state NEW -m tcp --dport 80 -j ACCEPT 
# allow https traffic
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m state --state NEW -m tcp --dport 443 -j ACCEPT 

  #if "SERVICES" !~ /APACHEINT/ && "SERVICES" !~ /TOMCAT_/
# allow http traffic for apache bound to port 80 directly.
-A IN -s ! 192.168.0.0/255.255.0.0 -p tcp -m state --state NEW -m tcp --dport 80 -j ACCEPT 
# allow https traffic internally
-A IN -s ! 192.168.0.0/255.255.0.0 -p tcp -m state --state NEW -m tcp --dport 443 -j ACCEPT 
  #endif

  #if "SERVICES" =~ /TOMCAT/
# tomcat regular port. We don't allow external access except via 443/80. 
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 8080 -m state --state NEW -j ACCEPT 
# tomcat https port
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 8443 -m state --state NEW -j ACCEPT 
  #endif

#endif

#if "SERVICES" =~ /VPNOPEN/
# allow access to 192.168.8.16 through firewall to port 8088.
-A IN -s 192.168.0.0/255.255.0.0 -p tcp -m tcp --dport 8088 -m state --state NEW -j ACCEPT 
#endif

 
# ROUTING rules
####################################################################################

#####P* iptables/openvpn/routing
### POLICY
### Services accessible from openvpn connected hosts.
### APPLIES TO
### hosts accessing network via openvpn
### SYNOPSIS
### Allow tcp traffic, udp DNS and icmp traffic to/from systems
### DESCRIPTION
### Allows all tcp traffic subject to vpn host's access restrictions.
### Allows port 53 udp traffic (to selected dns servers)
### Allows icmp traffic again subject to firewalls for openvpn host.
#####
#if "SERVICES" =~ /VPNOPEN/
# allow tcp/icmp traffic into/out of the tunnels
# add rules down here as iptables-save dumps tables in alphabetic order.

-A ROUTING -d 192.168.0.0/16 -i tun+ -p tcp -j ACCEPT 
-A ROUTING -s 192.168.0.0/16 -o tun+ -p tcp -j ACCEPT 
-A ROUTING -d 192.168.0.0/16 -i tun+ -p icmp -j ACCEPT 
-A ROUTING -s 192.168.0.0/16 -o tun+ -p icmp -j ACCEPT 

## Allow dns queries from roadwarriors to our internal dns servers.
-A ROUTING -i tun+ -p udp -m udp --dport 53 -j ACCEPT 
-A ROUTING -s 192.168.0.0/255.255.0.0 -o tun+ -p udp -m udp --sport 53 -j ACCEPT
#endif

# external rules
################################################################################
 
#####P* iptables/external 
### POLICY drop spoofed traffic (RFC 1918) source addresses coming from outside 
### and allow ESTABLISHED,RELATED 
### APPLIES TO
### any VPNIPSEC hosts
### SYNOPSIS
### drop spoofed traffic
### DESCRIPTION
### drop spoofed traffic
#####
#if "SERVICES" =~ /\bVPNIPSEC\b/
-A external -s 192.168.0.0/255.255.0.0 -j DROP
-A external -s 10.0.0.0/255.0.0.0 -j DROP
-A external -s 172.16.0.0/255.240.0.0 -j DROP
-A external -m state --state RELATED,ESTABLISHED -j ACCEPT
#endif

COMMIT
